<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Entity;

use JMS\Serializer\Annotation\Type;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Plesk administrator information
 */
class Admin
{
    /**
     * The administrator&#39;s company name.
     *
     * @Type("string")
     * @var string
     */
    public $company;
    /**
     * The administrator&#39;s personal name.
     *
     * @Assert\NotBlank()
     * @Type("string")
     * @var string
     */
    public $name;
    /**
     * The administrator&#39;s phone number.
     *
     * @Type("string")
     * @var string
     */
    public $phone;
    /**
     * The administrator&#39;s fax number.
     *
     * @Type("string")
     * @var string
     */
    public $fax;
    /**
     * The administrator&#39;s e-mail address.
     *
     * @Assert\NotBlank()
     * @Assert\Email()
     * @Type("string")
     * @var string
     */
    public $email;
    /**
     * The administrator&#39;s street address.
     *
     * @Type("string")
     * @var string
     */
    public $address;
    /**
     * The name of the city where administrator lives.
     *
     * @Type("string")
     * @var string
     */
    public $city;
    /**
     * The name of state (for US citizens) or province where administrator lives.
     *
     * @Type("string")
     * @var string
     */
    public $state;
    /**
     * The administrator&#39;s zip/postal code.
     *
     * @Type("string")
     * @var string
     */
    public $post_code;
    /**
     * The name of the country where administrator lives.
     *
     * @Assert\Country()
     * @Type("string")
     * @var string
     */
    public $country;
    /**
     * It specifies whether Plesk announcement messages are sent to the administrator&#39;s e-mail.
     *
     * @Assert\Type("bool")
     * @Type("bool")
     * @var bool
     */
    public $send_announce;
    /**
     * The locale used by the administrator.
     *
     * @Assert\Locale()
     * @Type("string")
     * @var string
     */
    public $locale;
    /**
     * It specifies the information if the administrator has multiple sessions in Plesk.
     *
     * @Assert\Type("bool")
     * @Type("bool")
     * @var bool
     */
    public $multiple_sessions;
}
