<?php
// Copyright 1999-2020. Plesk International GmbH. All rights reserved.

namespace PleskExt\RestApi\v2\Entity;

use JMS\Serializer\Annotation\Type;
use Symfony\Component\Validator\Constraints as Assert;
use PleskExt\RestApi\v2\Constraints as ApiAssert;

class DatabaseUser
{
    /**
     * @Assert\Blank(groups={"post", "put"})
     * @Type("integer")
     * @var int
     */
    public $id;
    /**
     * @Assert\NotBlank(groups={"post"})
     * @Type("string")
     * @var string
     */
    public $login;
    /**
     * @Assert\Blank(groups={"put"})
     * @Type("integer")
     * @var int|null
     */
    public $database_id;
    /**
     * @ApiAssert\PasswordStrength(groups={"post", "put"})
     * @Assert\NotBlank(groups={"post"})
     * @Type("string")
     * @var string
     */
    public $password;
    /**
     * Webspace ID
     *
     * @Assert\Blank(groups={"put"})
     * @Type("PleskExt\RestApi\v2\Entity\DomainReference")
     * @var DomainReference|null
     */
    public $parent_domain;
    /**
     * @Assert\Blank(groups={"put"})
     * @Type("integer")
     * @var int|null
     */
    public $server_id;

    /**
     * @Assert\IsTrue(
     *     message="Either parent_domain and server_id, or database_id should be specified",
     *     groups={"post"}
     * )
     */
    public function isBoundToOneObject(): bool
    {
        return $this->database_id xor $this->server_id;
    }
}
