<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Entity\ErrorResponse;
use PleskExt\RestApi\v2\Entity\SuccessResponse;
use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\Entity\SecretKeyRequest;
use PleskExt\RestApi\v2\Entity\SecretKeyResponse;
use PleskExt\RestApi\v2\SDK;
use Slim\Http\Request;
use Slim\Http\Response;

class AuthKeys extends InvokableHandler
{
    /**
     * @Consumer(type=SecretKeyRequest::class)
     */
    protected function post(Request $request, Response $response)
    {
        $secretKeyRequest = $this->consume();

        $secretKey = new SecretKeyResponse();
        $secretKey->key = SDK\pm_Auth::createSecretKey(
            array_filter(array_merge((array)$secretKeyRequest->ip, (array)$secretKeyRequest->ips)) ?: null,
            $secretKeyRequest->description,
            $secretKeyRequest->login
        );

        return $response
            ->write($this->produce($secretKey))
            ->withStatus(201);
    }

    protected function delete(Request $request, Response $response)
    {
        SDK\pm_Auth::deleteSecretKey($request->getAttribute('key'));
        return $response->write($this->produce(new SuccessResponse));
    }
}
