<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Annotation\Producer;
use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\Mapper\Response as ResponseMapper;
use PleskExt\RestApi\v2\Mapper\Client as ClientMapper;
use PleskExt\RestApi\v2\Entity\Client as ClientEntity;
use PleskExt\RestApi\v2\SDK;
use Slim\Http\Request;
use Slim\Http\Response;

class ClientsId extends InvokableHandler
{
    /**
     * @Producer(mapper=ClientMapper::class)
     */
    protected function get(Request $request, Response $response)
    {
        $client = SDK\pm_Client::getByClientId($request->getAttribute('id'));

        return $response->write($this->produce($client));
    }

    /**
     * @Consumer(type=ClientEntity::class)
     * @Producer(mapper=ResponseMapper::class)
     */
    protected function put(Request $request, Response $response)
    {
        $client = SDK\pm_Client::getByClientId($request->getAttribute('id'));
        $client->update($this->consume());

        return $response->write($this->produce($client));
    }

    /**
     * @Producer(mapper=ResponseMapper::class)
     */
    protected function delete(Request $request, Response $response)
    {
        $client = SDK\pm_Client::getByClientId($request->getAttribute('id'));
        $client->delete();

        return $response->write($this->produce($client));
    }
}
