<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Annotation\Producer;
use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\Mapper\Domains as DomainsMapper;
use PleskExt\RestApi\v2\Mapper\Response as ResponseMapper;
use PleskExt\RestApi\v2\Entity\DomainRequest as DomainRequestEntity;
use PleskExt\RestApi\v2\SDK;
use Slim\Http\Request;
use Slim\Http\Response;

class Domains extends InvokableHandler
{
    /**
     * @Producer(mapper=DomainsMapper::class)
     */
    protected function get(Request $request, Response $response)
    {
        $domains = [];

        $name = $request->getQueryParam('name');
        if ($name) {
            try {
                $domains = [SDK\pm_Domain::getByName($name)];
            } catch (SDK\Exception\NotFoundException $e) {
            }
        } else {
            $domains = SDK\pm_Domain::getAllDomains();
        }

        return $response->write($this->produce($domains));
    }

    /**
     * @Consumer(type=DomainRequestEntity::class)
     * @Producer(mapper=ResponseMapper::class)
     */
    protected function post(Request $request, Response $response)
    {
        $domain = SDK\pm_Domain::create($this->consume());

        return $response
            ->write($this->produce($domain))
            ->withStatus(201);
    }
}
