<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Annotation\Producer;
use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\Mapper\Domain as DomainMapper;
use PleskExt\RestApi\v2\Mapper\Response as ResponseMapper;
use PleskExt\RestApi\v2\Entity\DomainRequest as DomainRequestEntity;
use PleskExt\RestApi\v2\SDK;
use Slim\Http\Request;
use Slim\Http\Response;

class DomainsId extends InvokableHandler
{
    /**
     * @Producer(mapper=DomainMapper::class)
     */
    protected function get(Request $request, Response $response)
    {
        $domain = SDK\pm_Domain::getByDomainId($request->getAttribute('id'));

        return $response->write($this->produce($domain));
    }

    /**
     * @Consumer(type=DomainRequestEntity::class)
     * @Producer(mapper=ResponseMapper::class)
     */
    protected function put(Request $request, Response $response)
    {
        $domain = SDK\pm_Domain::getByDomainId($request->getAttribute('id'));
        $domain->update($this->consume());

        return $response->write($this->produce($domain));
    }

    /**
     * @Producer(mapper=ResponseMapper::class)
     */
    protected function delete(Request $request, Response $response)
    {
        $domain = SDK\pm_Domain::getByDomainId($request->getAttribute('id'));
        $domain->delete();

        return $response->write($this->produce($domain));
    }
}
