<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\SDK;
use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Annotation\Producer;
use PleskExt\RestApi\v2\Mapper\Extensions as ExtensionsMapper;
use PleskExt\RestApi\v2\Mapper\Extension as ExtensionMapper;
use PleskExt\RestApi\v2\Entity\ExtensionInstallRequest;
use PleskExt\RestApi\v2\Entity\SuccessResponse;
use PleskExt\RestApi\v2\Exception\InvalidDataException;
use Slim\Http\Request;
use Slim\Http\Response;

class Extensions extends InvokableHandler
{
    /**
     * @Producer(mapper=ExtensionsMapper::class)
     */
    protected function get(Request $request, Response $response)
    {
        $extensions = SDK\pm_Extension::getExtensions();

        return $response->write($this->produce($extensions));
    }

    /**
     * @Consumer(type=ExtensionInstallRequest::class)
     * @Producer(mapper=ExtensionMapper::class)
     */
    protected function post(Request $request, Response $response)
    {
        /** @var ExtensionInstallRequest $requestData */
        $requestData = $this->consume();

        if ($requestData->id) {
            SDK\pm_Extension::installById($requestData->id);
        } elseif ($requestData->url) {
            SDK\pm_Extension::installByUrl($requestData->url);
        } elseif ($requestData->file) {
            SDK\pm_Extension::installByFile($requestData->file);
        } else {
            throw new InvalidDataException("Unsupported installation type");
        }

        return $response->write($this->serialize(new SuccessResponse));
    }
}
