<?php
// Copyright 1999-2020. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Annotation\Producer;
use PleskExt\RestApi\v2\Entity\FtpUserRequest;
use PleskExt\RestApi\v2\Entity\FtpUserUpdateRequest;
use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\Mapper\FtpUser as FtpUserMapper;
use PleskExt\RestApi\v2\Mapper\FtpUsers as FtpUsersMapper;
use PleskExt\RestApi\v2\SDK;
use PleskExt\RestApi\v2\Entity\SuccessResponse;
use Slim\Http\Request;
use Slim\Http\Response;

class FtpUsers extends InvokableHandler
{
    /**
     * @Producer(mapper=FtpUsersMapper::class)
     */
    protected function get(Request $request, Response $response)
    {
        if (null !== $name = $request->getQueryParam('name')) {
            $users = [SDK\pm_FtpUser::getByName($name)];
        } elseif (null !== $domainName = $request->getQueryParam('domain')) {
            $domain = SDK\pm_Domain::getByName($domainName);
            $users = SDK\pm_FtpUser::getForDomain($domain);
        } else {
            $users = SDK\pm_FtpUser::getAll();
        }

        return $response->write($this->produce($users));
    }

    /**
     * @Consumer(type=FtpUserUpdateRequest::class)
     */
    protected function put(Request $request, Response $response)
    {
        $user = SDK\pm_FtpUser::getByName($request->getAttribute('name'));
        $user->update($this->consume());

        return $response->write($this->produce(new SuccessResponse));
    }

    /**
     * @Consumer(type=FtpUserRequest::class)
     * @Producer(mapper=FtpUserMapper::class)
     */
    protected function post(Request $request, Response $response)
    {
        $user = SDK\pm_FtpUser::create($this->consume());
        return $response->write($this->produce($user));
    }

    protected function delete(Request $request, Response $response)
    {
        $user = SDK\pm_FtpUser::getByName($request->getAttribute('name'));
        $user->delete();

        return $response->write($this->produce(new SuccessResponse));
    }
}
